Exception: WifiWand::MethodNotImplementedError
- Defined in:
- lib/wifi_wand/errors.rb
Instance Method Summary collapse
Methods inherited from Error
#append_help_hint?, #display_message, #exception, #message_for_display
Instance Method Details
#to_s ⇒ Object
328 329 330 331 |
# File 'lib/wifi_wand/errors.rb', line 328 def to_s 'This method is not implemented in this base class. ' \ 'It must be implemented in, and called on, a subclass.' end |